@@ -1,27 +1,30 @@
 import logging
+logger = logging.getLogger(__name__)
 from coolname import generate_slug
-from ..factory import get_algo, get_env
 from ..utils import load_config, merge_params, normalize_routine
 from ..utils import config_list_to_dict
 from ..utils import run_routine as run
 
 
 def run_routine(args):
-    # Get env params
-    # TODO: throw an error in get_plugin rather than printing error logs
-    _, configs_env = get_env(args.env)
-    if configs_env is None: return
-
-    # Get algo params
-    _, configs_algo = get_algo(args.algo)
-    if configs_algo is None: return
-
-    # Normalize the algo and env params
     try:
+        from ..factory import get_algo, get_env
+    except Exception as e:
+        logger.error(e)
+        return
+
+    try:
+        # Get env params
+        _, configs_env = get_env(args.env)
+
+        # Get algo params
+        _, configs_algo = get_algo(args.algo)
+
+        # Normalize the algo and env params
         params_env = load_config(args.env_params)
         params_algo = load_config(args.algo_params)
     except Exception as e:
-        logging.error(e)
+        logger.error(e)
         return
     params_env = merge_params(configs_env['params'], params_env)
     params_algo = merge_params(configs_algo['params'], params_algo)
@@ -35,7 +38,7 @@ def run_routine(args):
         except KeyError:
             configs_routine['constraints'] = None
     except Exception as e:
-        logging.error(e)
+        logger.error(e)
         return
 
     # Compose the routine
@@ -55,11 +58,10 @@ def run_routine(args):
     try:
         routine = normalize_routine(routine)
     except Exception as e:
-        logging.error(e)
+        logger.error(e)
         return
 
     try:
         run(routine, args.yes, args.save, args.verbose)
     except Exception as e:
-        raise e
-        logging.error(e)
+        logger.error(e)
